﻿using System;
using System.Collections.Generic;
using Ozeki.Network;
using Ozeki.VoIP;

namespace CallQueue
{
    class MyPBX : PBXBase
    {
        string localAddress;

        public MyPBX(string localAddress, int minPortRange, int maxPortRange) : base(minPortRange, maxPortRange)
        {
            Console.WriteLine("PBX starting...");
            Console.WriteLine("Local address: " + localAddress);

            this.localAddress = localAddress;
        }

        protected override void OnStart()
        {
            SetListenPort(localAddress, 5060, TransportType.Udp);
            Console.WriteLine("Listened port: 5060(UDP)");

            InitCallQueue();

            Console.WriteLine("PBX started.");
            base.OnStart();
        }

        protected override RegisterResult OnRegisterReceived(ISIPExtension extension, SIPAddress from, int expires)
        {
            Console.WriteLine("Register received from: " + extension.ExtensionID);
            return base.OnRegisterReceived(extension, from, expires);
        }

        protected override void OnUnregisterReceived(ISIPExtension extension)
        {
            Console.WriteLine("Unregister received from: " + extension.ExtensionID);
            base.OnUnregisterReceived(extension);
        }

        protected override void OnCallRequestReceived(ISessionCall call)
        {
            Console.WriteLine("Call request received. Caller: " + call.DialInfo.CallerID + " callee: " + call.DialInfo.Dialed);
            base.OnCallRequestReceived(call);
        }

        private void InitCallQueue()
        {
            var extensionContainer = GetService<IExtensionContainer>();
            var callManager = GetService<ICallManager>();

            var callQueueMembers = new List<string>();
            callQueueMembers.Add("855");
            var callQueueExtension = new CallQueueExtension("800", extensionContainer, callManager, callQueueMembers);
            extensionContainer.TryAddExtension(callQueueExtension);
        }
    }
}
